/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.freemarkerdor;

import java.io.IOException;
import java.util.Iterator;
import java.util.Properties;
import java.util.ServiceLoader;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import org.openide.util.Exceptions;

/** Send emails.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public abstract class EmailService {
    private static EmailService DEFAULT;
    
    public abstract void sendEmail(
        String address,
        String subject,
        String text
    ) throws IOException;

    public static synchronized EmailService getDefault() {
        if (DEFAULT == null) {
            Iterator<EmailService> it = ServiceLoader.load(EmailService.class).iterator();
            DEFAULT = it.hasNext() ? it.next() : new Impl();
        }
        return DEFAULT;
    }

    private static class Impl extends EmailService {
        private final Session session;
        public Impl() {
            Properties props = System.getProperties();
            final String host = "mail.smtp.host";
            if (props.get(host) == null) {
                props.put(host,"localhost");
            }
            session = Session.getDefaultInstance(props, null);
        }

        @Override
        public void sendEmail(String address, String subject, String text) throws IOException {
            try {
                MimeMessage message = new MimeMessage(session);
                message.setFrom(new InternetAddress("quoridor@xelfi.cz"));
                message.setSentDate(new Date());
                message.addRecipient(Message.RecipientType.TO, new InternetAddress(address));
                message.setSubject(subject);
                message.setText(text);
                Transport.send(message);
            } catch (MessagingException ex) {
                throw new IOException(ex);
            }

        }
    }
}
